@@ -51,11 +51,14 @@ class sdf::CameraPrivate
   /// \brief The SDF element pointer used during load.
   public: sdf::ElementPtr sdf;
 
+  /// \brief Camera info topic.
+  public: std::string cameraInfoTopic = "";
+
   /// \brief Name of the camera.
   public: std::string name = "";
 
   /// \brief Horizontal fied of view.
-  public: ignition::math::Angle hfov{1.047};
+  public: gz::math::Angle hfov{1.047};
 
   /// \brief Image width.
   public: uint32_t imageWidth{320};
@@ -115,10 +118,10 @@ class sdf::CameraPrivate
   public: double distortionP2{0.0};
 
   /// \brief The distortion center or principal point
-  public: ignition::math::Vector2d distortionCenter{0.5, 0.5};
+  public: gz::math::Vector2d distortionCenter{0.5, 0.5};
 
   /// \brief Pose of the link
-  public: ignition::math::Pose3d pose = ignition::math::Pose3d::Zero;
+  public: gz::math::Pose3d pose = gz::math::Pose3d::Zero;
 
   /// \brief Frame of the pose.
   public: std::string poseRelativeTo = "";
@@ -145,7 +148,7 @@ class sdf::CameraPrivate
   public: std::string lensFun{"tan"};
 
   /// \brief Lens cutoff angle.
-  public: ignition::math::Angle lensCutoffAngle{IGN_PI_2};
+  public: gz::math::Angle lensCutoffAngle{IGN_PI_2};
 
   /// \brief lens environment texture size.
   public: int lensEnvTextureSize{256};
@@ -162,9 +165,30 @@ class sdf::CameraPrivate
   /// \brief lens instrinsics cy.
   public: double lensIntrinsicsCy{120.0};
 
+  /// \brief lens projection fx
+  public: double lensProjectionFx{277.0};
+
+  /// \brief lens projection fy
+  public: double lensProjectionFy{277.0};
+
+  /// \brief lens projection cx
+  public: double lensProjectionCx{160.0};
+
+  /// \brief lens projection cy
+  public: double lensProjectionCy{120.0};
+
+  /// \brief lens projection tx
+  public: double lensProjectionTx{0.0};
+
+  /// \brief lens projection ty
+  public: double lensProjectionTy{0.0};
+
   /// \brief lens instrinsics s.
   public: double lensIntrinsicsS{1.0};
 
+  /// \brief True if this camera has custom projection values
+  public: bool hasProjection = false;
+
   /// \brief Visibility mask of a camera. Defaults to 0xFFFFFFFF
   public: uint32_t visibilityMask{4294967295u};
 };
@@ -235,7 +259,12 @@ Errors Camera::Load(ElementPtr _sdf)
   // Read the camera's name
   loadName(_sdf, this->dataPtr->name);
 
-  this->dataPtr->hfov = _sdf->Get<ignition::math::Angle>("horizontal_fov",
+  this->dataPtr->cameraInfoTopic = _sdf->Get<std::string>("camera_info_topic",
+      this->dataPtr->cameraInfoTopic).first;
+  if (this->dataPtr->cameraInfoTopic == "__default__")
+    this->dataPtr->cameraInfoTopic = "";
+
+  this->dataPtr->hfov = _sdf->Get<gz::math::Angle>("horizontal_fov",
       this->dataPtr->hfov).first;
 
   // Read the distortion
@@ -254,7 +283,7 @@ Errors Camera::Load(ElementPtr _sdf)
     this->dataPtr->distortionP2 = elem->Get<double>("p2",
       this->dataPtr->distortionP2).first;
 
-    this->dataPtr->distortionCenter = elem->Get<ignition::math::Vector2d>(
+    this->dataPtr->distortionCenter = elem->Get<gz::math::Vector2d>(
         "center", this->dataPtr->distortionCenter).first;
   }
 
@@ -351,7 +380,7 @@ Errors Camera::Load(ElementPtr _sdf)
         this->dataPtr->lensType).first;
     this->dataPtr->lensScaleToHfov = elem->Get<bool>("scale_to_hfov",
         this->dataPtr->lensScaleToHfov).first;
-    this->dataPtr->lensCutoffAngle = elem->Get<ignition::math::Angle>(
+    this->dataPtr->lensCutoffAngle = elem->Get<gz::math::Angle>(
         "cutoff_angle", this->dataPtr->lensCutoffAngle).first;
     this->dataPtr->lensEnvTextureSize = elem->Get<int>("env_texture_size",
         this->dataPtr->lensEnvTextureSize).first;
@@ -385,6 +414,23 @@ Errors Camera::Load(ElementPtr _sdf)
       this->dataPtr->lensIntrinsicsS = intrinsics->Get<double>("s",
           this->dataPtr->lensIntrinsicsS).first;
     }
+
+    if (elem->HasElement("projection")) {
+      sdf::ElementPtr projection = elem->GetElement("projection");
+      this->dataPtr->lensProjectionFx = projection->Get<double>("p_fx",
+          this->dataPtr->lensProjectionFx).first;
+      this->dataPtr->lensProjectionFy = projection->Get<double>("p_fy",
+          this->dataPtr->lensProjectionFy).first;
+      this->dataPtr->lensProjectionCx = projection->Get<double>("p_cx",
+          this->dataPtr->lensProjectionCx).first;
+      this->dataPtr->lensProjectionCy = projection->Get<double>("p_cy",
+          this->dataPtr->lensProjectionCy).first;
+      this->dataPtr->lensProjectionTx = projection->Get<double>("tx",
+          this->dataPtr->lensProjectionTx).first;
+      this->dataPtr->lensProjectionTy = projection->Get<double>("ty",
+          this->dataPtr->lensProjectionTy).first;
+      this->dataPtr->hasProjection = true;
+    }
   }
 
   if (_sdf->HasElement("visibility_mask"))
@@ -396,6 +442,18 @@ Errors Camera::Load(ElementPtr _sdf)
   return errors;
 }
 
+/////////////////////////////////////////////////
+std::string Camera::CameraInfoTopic() const
+{
+  return this->dataPtr->cameraInfoTopic;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetCameraInfoTopic(const std::string &_cameraInfoTopic)
+{
+  this->dataPtr->cameraInfoTopic = _cameraInfoTopic;
+}
+
 /////////////////////////////////////////////////
 sdf::ElementPtr Camera::Element() const
 {
@@ -415,13 +473,13 @@ void Camera::SetName(const std::string &_name)
 }
 
 /////////////////////////////////////////////////
-ignition::math::Angle Camera::HorizontalFov() const
+gz::math::Angle Camera::HorizontalFov() const
 {
   return this->dataPtr->hfov;
 }
 
 /////////////////////////////////////////////////
-void Camera::SetHorizontalFov(const ignition::math::Angle &_hfov)
+void Camera::SetHorizontalFov(const gz::math::Angle &_hfov)
 {
   this->dataPtr->hfov = _hfov;
 }
@@ -604,8 +662,8 @@ bool Camera::operator==(const Camera &_cam) const
     this->ImageWidth() == _cam.ImageWidth() &&
     this->ImageHeight() == _cam.ImageHeight() &&
     this->PixelFormat() == _cam.PixelFormat() &&
-    ignition::math::equal(this->NearClip(), _cam.NearClip()) &&
-    ignition::math::equal(this->FarClip(), _cam.FarClip()) &&
+    gz::math::equal(this->NearClip(), _cam.NearClip()) &&
+    gz::math::equal(this->FarClip(), _cam.FarClip()) &&
     this->SaveFrames() == _cam.SaveFrames() &&
     this->SaveFramesPath() == _cam.SaveFramesPath() &&
     this->ImageNoise() == _cam.ImageNoise() &&
@@ -691,26 +749,26 @@ void Camera::SetDistortionP2(double _p2)
 }
 
 //////////////////////////////////////////////////
-const ignition::math::Vector2d &Camera::DistortionCenter() const
+const gz::math::Vector2d &Camera::DistortionCenter() const
 {
   return this->dataPtr->distortionCenter;
 }
 
 //////////////////////////////////////////////////
 void Camera::SetDistortionCenter(
-                const ignition::math::Vector2d &_center) const
+                const gz::math::Vector2d &_center) const
 {
   this->dataPtr->distortionCenter = _center;
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Pose3d &Camera::Pose() const
+const gz::math::Pose3d &Camera::Pose() const
 {
   return this->RawPose();
 }
 
 /////////////////////////////////////////////////
-const ignition::math::Pose3d &Camera::RawPose() const
+const gz::math::Pose3d &Camera::RawPose() const
 {
   return this->dataPtr->pose;
 }
@@ -728,13 +786,13 @@ const std::string &Camera::PoseRelativeTo() const
 }
 
 /////////////////////////////////////////////////
-void Camera::SetPose(const ignition::math::Pose3d &_pose)
+void Camera::SetPose(const gz::math::Pose3d &_pose)
 {
   this->SetRawPose(_pose);
 }
 
 /////////////////////////////////////////////////
-void Camera::SetRawPose(const ignition::math::Pose3d &_pose)
+void Camera::SetRawPose(const gz::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -836,13 +894,13 @@ void Camera::SetLensFunction(const std::string &_fun)
 }
 
 /////////////////////////////////////////////////
-ignition::math::Angle Camera::LensCutoffAngle() const
+gz::math::Angle Camera::LensCutoffAngle() const
 {
   return this->dataPtr->lensCutoffAngle;
 }
 
 /////////////////////////////////////////////////
-void Camera::SetLensCutoffAngle(const ignition::math::Angle &_angle)
+void Camera::SetLensCutoffAngle(const gz::math::Angle &_angle)
 {
   this->dataPtr->lensCutoffAngle = _angle;
 }
@@ -907,6 +965,84 @@ void Camera::SetLensIntrinsicsCy(double _cy)
   this->dataPtr->lensIntrinsicsCy = _cy;
 }
 
+/////////////////////////////////////////////////
+double Camera::LensProjectionFx() const
+{
+  return this->dataPtr->lensProjectionFx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionFx(double _fx_p)
+{
+  this->dataPtr->lensProjectionFx = _fx_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionFy() const
+{
+  return this->dataPtr->lensProjectionFy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionFy(double _fy_p)
+{
+  this->dataPtr->lensProjectionFy = _fy_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionCx() const
+{
+  return this->dataPtr->lensProjectionCx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionCx(double _cx_p)
+{
+  this->dataPtr->lensProjectionCx = _cx_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionCy() const
+{
+  return this->dataPtr->lensProjectionCy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionCy(double _cy_p)
+{
+  this->dataPtr->lensProjectionCy = _cy_p;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionTx() const
+{
+  return this->dataPtr->lensProjectionTx;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionTx(double _tx)
+{
+  this->dataPtr->lensProjectionTx = _tx;
+  this->dataPtr->hasProjection = true;
+}
+
+/////////////////////////////////////////////////
+double Camera::LensProjectionTy() const
+{
+  return this->dataPtr->lensProjectionTy;
+}
+
+/////////////////////////////////////////////////
+void Camera::SetLensProjectionTy(double _ty)
+{
+  this->dataPtr->lensProjectionTy = _ty;
+  this->dataPtr->hasProjection = true;
+}
+
 /////////////////////////////////////////////////
 double Camera::LensIntrinsicsSkew() const
 {
@@ -972,3 +1108,9 @@ void Camera::SetVisibilityMask(uint32_t _mask)
 {
   this->dataPtr->visibilityMask = _mask;
 }
+
+/////////////////////////////////////////////////
+bool Camera::HasLensProjection() const
+{
+  return this->dataPtr->hasProjection;
+}
